%define game_version 5.8.0

Name:		minetest
Version:	5.10.0
Release:	%mkrel 1
Summary:	Open source voxel game engine and InfiniMiner/Minecraft-inspired game
Group:		Games/Simulation
License:	LGPLv2+ and CC-BY-SA 3.0
URL:		https://luanti.org
Source0:	https://github.com/minetest/minetest/archive/%{version}/%{name}-%{version}.tar.gz
Source1:	https://github.com/minetest/minetest_game/archive/%{game_version}/%{name}_game-%{game_version}.tar.gz

BuildRequires:	cmake
BuildRequires:	gettext
BuildRequires:	gmp-devel
BuildRequires:	spatialindex-devel
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(jsoncpp)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(hiredis)
BuildRequires:	pkgconfig(leveldb)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(luajit)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(vorbisfile)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xi)
BuildRequires:	pkgconfig(zlib)

# Extra deps for irrlichtMT:
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xft)
BuildRequires:	pkgconfig(xxf86vm)

%description
Minetest in an open source voxel game engine. You can play one of the many
games designed by its community, mod a game to your liking, make your own
game, or play on a multiplayer server.

The base package comes with the default Minetest game and some pre-installed
mods, which should provide a gaming experience similar to Minecraft.

%prep
%autosetup -p1 -a 1

# purge bundled jsoncpp and lua, and gmp
rm -rf lib/jsoncpp lib/lua lib/gmp

%build
%cmake \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DCUSTOM_BINDIR:STRING=%{_gamesbindir} \
	-DCUSTOM_LOCALEDIR:STRING=%{_datadir}/locale \
	-DCUSTOM_SHAREDIR:STRING=%{_gamesdatadir}/luanti \
	-DENABLE_CURL:BOOL=ON \
	-DENABLE_FREETYPE:BOOL=ON \
	-DENABLE_GETTEXT:BOOL=ON \
	-DENABLE_LEVELDB:BOOL=ON \
	-DENABLE_REDIS:BOOL=ON \
	-DENABLE_SOUND:BOOL=ON \
	-DENABLE_SPATIAL:BOOL=ON \
	-DENABLE_SYSTEM_GMP:BOOL=ON \
	-DENABLE_SYSTEM_JSONCPP:BOOL=ON
%cmake_build

%install
%cmake_install

install -d %{buildroot}%{_gamesdatadir}/luanti/games/%{name}_game
cp -r %{name}_game-%{game_version}/* %{buildroot}%{_gamesdatadir}/luanti/games/%{name}_game

rm -rf %{buildroot}%{_gamesdatadir}/luanti/client/serverlist/.gitignore

%find_lang luanti

%files -f luanti.lang
%doc doc/*.{txt,md} doc/*.png README.md minetest.conf.example
%doc %{_docdir}/luanti/
%license LICENSE.txt
%{_gamesbindir}/%{name}
%{_gamesbindir}/luanti
%{_gamesdatadir}/luanti/
%{_datadir}/applications/net.minetest.%{name}.desktop
%{_metainfodir}/net.minetest.%{name}.metainfo.xml
%{_iconsdir}/hicolor/*/apps/luanti.*
%{_mandir}/man6/luanti.6*
%{_mandir}/man6/luantiserver.6*


%changelog
* Fri Nov 15 2024 daviddavid <daviddavid> 5.10.0-1.mga10
+ Revision: 2116048
- new version: 5.10.0 (new name is now luanti)

* Tue Sep 24 2024 daviddavid <daviddavid> 5.9.1-1.mga10
+ Revision: 2100959
- new version: 5.9.1

* Thu Aug 15 2024 daviddavid <daviddavid> 5.9.0-1.mga10
+ Revision: 2086620
- new version: 5.9.0
- IrrlichtMt is now included in the minetest source code
  https://github.com/minetest/minetest/releases/tag/5.9.0

* Sat Apr 20 2024 daviddavid <daviddavid> 5.8.0-3.mga10
+ Revision: 2060083
- backport upstream patch to add missing header for gcc-14
- enable spatial support

* Fri Mar 29 2024 daviddavid <daviddavid> 5.8.0-2.mga10
+ Revision: 2053074
- enable hiredis support

* Fri Feb 02 2024 daviddavid <daviddavid> 5.8.0-1.mga10
+ Revision: 2036724
- new version: 5.8.0

* Sun Oct 29 2023 daviddavid <daviddavid> 5.7.0-2.mga10
+ Revision: 2002568
- rebuild for new jsoncpp 1.9.5

* Sat Jul 01 2023 akien <akien> 5.7.0-1.mga9
+ Revision: 1963340
- Version 5.7.0

* Fri Mar 17 2023 daviddavid <daviddavid> 5.6.1-2.mga9
+ Revision: 1949540
- fix dangling links:
  /usr/share/doc/minetest/mkdocs/docs/img/favicon.ico -> ../../../../misc/minetest-icon.ico

* Thu Dec 29 2022 daviddavid <daviddavid> 5.6.1-1.mga9
+ Revision: 1927581
- new version: 5.6.1

* Wed Mar 30 2022 umeabot <umeabot> 5.5.0-2.mga9
+ Revision: 1834893
- Mageia 9 Mass Rebuild

* Tue Feb 01 2022 akien <akien> 5.5.0-1.mga9
+ Revision: 1770821
- Version 5.5.0
- Now using its own fork of irrlicht

* Sat Apr 17 2021 akien <akien> 5.4.1-1.mga9
+ Revision: 1716261
- Version 5.4.1

* Sun Nov 29 2020 luigiwalser <luigiwalser> 5.3.0-2.mga8
+ Revision: 1650315
- rebuild for jsoncpp

* Mon Oct 19 2020 akien <akien> 5.3.0-1.mga8
+ Revision: 1637071
- Version 5.3.0

* Tue Apr 07 2020 akien <akien> 5.2.0-1.mga8
+ Revision: 1565414
- Version 5.2.0

* Sat Feb 15 2020 umeabot <umeabot> 5.0.1-2.mga8
+ Revision: 1525408
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Tue Apr 16 2019 zezinho <zezinho> 5.0.1-1.mga7
+ Revision: 1391673
- new version 5.0.1

* Wed Mar 06 2019 akien <akien> 5.0.0-1.mga7
+ Revision: 1371939
- Version 5.0.0

* Sun Sep 23 2018 umeabot <umeabot> 0.4.17.1-2.mga7
+ Revision: 1299544
- Mageia 7 Mass Rebuild

* Sat Aug 11 2018 akien <akien> 0.4.17.1-1.mga7
+ Revision: 1251040
- Version 0.4.17.1

* Mon Jun 04 2018 akien <akien> 0.4.17-1.mga7
+ Revision: 1234492
- Version 0.4.17

* Fri Feb 16 2018 daviddavid <daviddavid> 0.4.16-4.mga7
+ Revision: 1201719
- add fedora patch to fix build with luajit 2.1

* Fri Oct 13 2017 eatdirt <eatdirt> 0.4.16-3.mga7
+ Revision: 1171572
- Rebuild for new jsoncpp

* Sat Aug 26 2017 akien <akien> 0.4.16-2.mga7
+ Revision: 1148009
- Enable system jsoncpp, upstream GH-1793 appears to be fixed

* Sat Jun 03 2017 akien <akien> 0.4.16-1.mga6
+ Revision: 1106388
- Version 0.4.16

* Fri Mar 24 2017 akien <akien> 0.4.15-3.mga6
+ Revision: 1094693
- Rebuild for jthread 1.3.3

* Sun Jan 01 2017 akien <akien> 0.4.15-2.mga6
+ Revision: 1079435
- Rebuild for leveldb 1.19

* Fri Dec 23 2016 akien <akien> 0.4.15-1.mga6
+ Revision: 1076544
- Version 0.4.15

* Mon May 16 2016 akien <akien> 0.4.14-1.mga6
+ Revision: 1016150
- Version 0.4.14

* Wed Mar 16 2016 daviddavid <daviddavid> 0.4.13-3.mga6
+ Revision: 991760
- rename and rediff unappliable desktop patch (since fixed autopatch)

* Mon Feb 15 2016 umeabot <umeabot> 0.4.13-2.mga6
+ Revision: 961407
- Mageia 6 Mass Rebuild

* Sun Sep 13 2015 akien <akien> 0.4.13-1.mga6
+ Revision: 878931
- Build against system gmp
- Version 0.4.13

* Sat Aug 29 2015 cjw <cjw> 0.4.12-2.mga6
+ Revision: 870813
- rebuild with gcc 5

* Sun Feb 22 2015 akien <akien> 0.4.12-1.mga5
+ Revision: 816390
- Add patch inspired from a Debian freeminer patch to properly lookup for the translations
- Version 0.4.12

* Sat Dec 27 2014 akien <akien> 0.4.11-1.mga5
+ Revision: 806557
- Version 0.4.11

* Mon Dec 01 2014 akien <akien> 0.4.10-6.mga5
+ Revision: 800225
- Enable cURL support for online multiplayer features
- System jsoncpp does not work with cURL support, used bundled version
- Disable hiredis support (optional)

* Wed Oct 15 2014 umeabot <umeabot> 0.4.10-5.mga5
+ Revision: 745299
- Second Mageia 5 Mass Rebuild

* Wed Sep 17 2014 akien <akien> 0.4.10-4.mga5
+ Revision: 693180
- Enable freetype2 and leveldb support
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Wed Aug 27 2014 akien <akien> 0.4.10-1.mga5
+ Revision: 668844
- Fix unfound translations using a symlink
- Version 0.4.10

* Sun Feb 09 2014 akien <akien> 0.4.9-1.mga5
+ Revision: 587283
- New upstream release 0.4.9: http://dev.minetest.net/Changelog#0.4.8_.E2.86.92_0.4.9

* Sun Nov 24 2013 akien <akien> 0.4.8-1.mga5
+ Revision: 552718
- New upstream release 0.4.8: http://dev.minetest.net/Changelog#0.4.7_.E2.86.92_0.4.8
- Removed jthread patch, no longer necessary
- Added patch to fix locale dir instead of relying on a sed instruction
- Added patch to change desktop category

* Mon Oct 21 2013 umeabot <umeabot> 0.4.7-3.mga4
+ Revision: 539913
- Mageia 4 Mass Rebuild

* Tue Oct 08 2013 dams <dams> 0.4.7-2.mga4
+ Revision: 493064
- update specfile
- clean %%cmake options
- enable back parallel build

* Tue Oct 08 2013 dams <dams> 0.4.7-1.mga4
+ Revision: 493051
- new version 0.4.7
- add a patch to fix build with jthread
- add a patch to fix jsoncpp deps

* Sat Jan 12 2013 umeabot <umeabot> 0.4.3-3.mga3
+ Revision: 360093
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 12 2012 dams <dams> 0.4.3-2.mga3
+ Revision: 293095
- do not use embedded jthread anymore (+ patch from Mandriva to fix build)

* Mon Sep 10 2012 dams <dams> 0.4.3-1.mga3
+ Revision: 291962
- add a patch to fix build of jthread (embedded): pthread needed
- new version 0.4.3
- clean specfile
- remove useless patch
- update %%cmake options
- imported package minetest


* Thu Jul 26 2012 Andrey Bondrov <abondrov@mandriva.org> 0.4.1-1mdv2010.1
+ Revision: 811164
- Don't use patch for older MDV releases

* Thu Jul 26 2012 Andrey Bondrov <abondrov@mandriva.org> 0.4.1-1
+ Revision: 811146
- Add patch0 to fix build against new jthread
- New version 0.4.1, update BuildRequires and files

* Thu Nov 10 2011 Andrey Bondrov <abondrov@mandriva.org> 0.3.1-1
+ Revision: 729589
- imported package minetest

